@@ -24,7 +24,7 @@
 #include <akonadi/agentinstancecreatejob.h>
 
 #include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QMetaMethod>
 #include <QVariant>
@@ -163,4 +163,3 @@ void Resource::reconfigure()
 }
 
 
-#include "resource.moc"
