@@ -481,4 +481,4 @@ void SendJob::abort()
   }
 }
 
-#include "sendjob.moc"
+#include "moc_sendjob.cpp"
