@@ -32,7 +32,7 @@
 
 #include <KCheckableProxyModel>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KPushButton>
 #include <KLineEdit>
 #include <KDebug>
@@ -45,7 +45,7 @@
 
 NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWidget *parent)
     : QWidget(parent),
-      mCanUpdateStatus(false)
+      mNeedUpdate(false)
 {
     QVBoxLayout *vbox = new QVBoxLayout;
 
@@ -59,6 +59,7 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     mModel = new Akonadi::EntityTreeModel( mChangeRecorder, this );
     // Set the model to show only collections, not items.
     mModel->setItemPopulationStrategy( Akonadi::EntityTreeModel::NoItemPopulation );
+    connect(mModel, SIGNAL(collectionTreeFetched(Akonadi::Collection::List)), SLOT(slotCollectionTreeFetched()));
 
     Akonadi::CollectionFilterProxyModel *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel( this );
     mimeTypeProxy->setExcludeVirtualCollections( true );
@@ -71,9 +72,6 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     mCheckProxy->setSelectionModel( mSelectionModel );
     mCheckProxy->setSourceModel( mimeTypeProxy );
 
-    connect(mModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(slotCollectionsInserted(QModelIndex,int,int)));
-
 
     mCollectionFilter = new KRecursiveFilterProxyModel(this);
     mCollectionFilter->setSourceModel(mCheckProxy);
@@ -108,7 +106,6 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     hbox->addWidget(button);
     hbox->addStretch(1);
     setLayout(vbox);
-    QTimer::singleShot(1000, this, SLOT(slotUpdateCollectionStatus()));
 }
 
 NewMailNotifierSelectCollectionWidget::~NewMailNotifierSelectCollectionWidget()
@@ -116,6 +113,15 @@ NewMailNotifierSelectCollectionWidget::~NewMailNotifierSelectCollectionWidget()
 
 }
 
+void NewMailNotifierSelectCollectionWidget::slotCollectionTreeFetched()
+{
+    if (!mNeedUpdate) {
+        mNeedUpdate = true;
+        QTimer::singleShot(1000, this, SLOT(slotUpdateCollectionStatus()));
+    }
+    mFolderView->expandAll();
+}
+
 void NewMailNotifierSelectCollectionWidget::slotSetCollectionFilter(const QString &filter)
 {
     mCollectionFilter->setFilterWildcard(filter);
@@ -124,7 +130,6 @@ void NewMailNotifierSelectCollectionWidget::slotSetCollectionFilter(const QStrin
 
 void NewMailNotifierSelectCollectionWidget::slotUpdateCollectionStatus()
 {
-    mCanUpdateStatus = true;
     updateStatus(QModelIndex());
 }
 
@@ -140,9 +145,6 @@ void NewMailNotifierSelectCollectionWidget::slotUnselectAllCollections()
 
 void NewMailNotifierSelectCollectionWidget::updateStatus(const QModelIndex &parent)
 {
-    if (!mCanUpdateStatus)
-        return;
-
     const int nbCol = mCheckProxy->rowCount( parent );
     for ( int i = 0; i < nbCol; ++i ) {
         const QModelIndex child = mCheckProxy->index( i, 0, parent );
@@ -156,6 +158,7 @@ void NewMailNotifierSelectCollectionWidget::updateStatus(const QModelIndex &pare
         }
         updateStatus( child );
     }
+    mNeedUpdate = false;
 }
 
 void NewMailNotifierSelectCollectionWidget::forceStatus(const QModelIndex &parent, bool status)
@@ -168,11 +171,6 @@ void NewMailNotifierSelectCollectionWidget::forceStatus(const QModelIndex &paren
     }
 }
 
-void NewMailNotifierSelectCollectionWidget::slotCollectionsInserted(const QModelIndex &, int, int)
-{
-    mFolderView->expandAll();
-}
-
 void NewMailNotifierSelectCollectionWidget::updateCollectionsRecursive(const QModelIndex &parent)
 {
     const int nbCol = mCheckProxy->rowCount( parent );
@@ -220,4 +218,3 @@ void NewMailNotifierSelectCollectionWidget::slotModifyJobDone(KJob* job)
 }
 
 
-#include "newmailnotifierselectcollectionwidget.moc"
