@@ -27,9 +27,12 @@
 #include <kabc/contactgrouptool.h>
 #include <kabc/vcardconverter.h>
 
+namespace Akonadi_Contacts_Resource {
+class ContactsResourceSettings;
+}
 class QDir;
 
-class ContactsResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::Observer
+class ContactsResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::ObserverV2
 {
   Q_OBJECT
 
@@ -53,18 +56,27 @@ class ContactsResource : public Akonadi::ResourceBase, public Akonadi::AgentBase
 
     virtual void collectionAdded( const Akonadi::Collection &collection, const Akonadi::Collection &parent );
     virtual void collectionChanged( const Akonadi::Collection &collection );
+    // do not hide the other variant, use implementation from base class
+    // which just forwards to the one above
+    using Akonadi::AgentBase::ObserverV2::collectionChanged;
     virtual void collectionRemoved( const Akonadi::Collection &collection );
 
+    virtual void itemMoved( const Akonadi::Item &item, const Akonadi::Collection &collectionSource,
+                            const Akonadi::Collection &collectionDestination );
+    virtual void collectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &collectionSource,
+                                  const Akonadi::Collection &collectionDestination );
+
   private:
     Akonadi::Collection::List createCollectionsForDirectory( const QDir &parentDirectory,
                                                              const Akonadi::Collection &parentCollection ) const;
     QString baseDirectoryPath() const;
     void initializeDirectory( const QString &path ) const;
-    Akonadi::Collection::Rights supportedRights() const;
+    Akonadi::Collection::Rights supportedRights( bool isResourceCollection ) const;
     QString directoryForCollection( const Akonadi::Collection& collection ) const;
 
   private:
     QStringList mSupportedMimeTypes;
+    Akonadi_Contacts_Resource::ContactsResourceSettings *mSettings;
 };
 
 #endif
