@@ -116,8 +116,6 @@ void DavGroupwareResource::collectionRemoved( const Akonadi::Collection &collect
   kDebug() << "Removing collection " << collection.remoteId();
 
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return;
   }
 
@@ -229,8 +227,6 @@ void DavGroupwareResource::retrieveCollections()
   mSyncErrorNotified = false;
 
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return;
   }
 
@@ -248,8 +244,6 @@ void DavGroupwareResource::retrieveItems( const Akonadi::Collection &collection
   kDebug() << "Retrieving items for collection " << collection.remoteId();
 
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return;
   }
 
@@ -281,8 +275,6 @@ bool DavGroupwareResource::retrieveItem( const Akonadi::Item &item, const QSet<Q
   kDebug() << "Retrieving single item. Remote id = " << item.remoteId();
 
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return false;
   }
 
@@ -312,8 +304,6 @@ void DavGroupwareResource::itemAdded( const Akonadi::Item &item, const Akonadi::
       << ". Collection remote id = " << collection.remoteId();
 
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return;
   }
 
@@ -347,8 +337,6 @@ void DavGroupwareResource::itemChanged( const Akonadi::Item &item, const QSet<QB
       << ". Remote id = " << item.remoteId();
 
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return;
   }
 
@@ -374,8 +362,6 @@ void DavGroupwareResource::itemChanged( const Akonadi::Item &item, const QSet<QB
 void DavGroupwareResource::itemRemoved( const Akonadi::Item &item )
 {
   if ( !configurationIsValid() ) {
-    emit status( Broken, i18n( "The resource is not configured yet" ) );
-    cancelTask( i18n( "The resource is not configured yet" ) );
     return;
   }
 
@@ -738,10 +724,9 @@ void DavGroupwareResource::onItemAddedFinished( KJob *job )
   Akonadi::Item item = createJob->property( "item" ).value<Akonadi::Item>();
   item.setRemoteId( davItem.url() );
 
-
   if ( createJob->error() ) {
     kError() << "Error when uploading item:" << createJob->error() << createJob->errorString();
-    cancelTask( i18n( "Unable to add item: %1", createJob->errorString() ) );
+    retryAfterFailure(createJob->errorString());
     return;
   }
 
@@ -769,7 +754,7 @@ void DavGroupwareResource::onItemChangedFinished( KJob *job )
 
   if ( modifyJob->error() ) {
     kError() << "Error when uploading item:" << modifyJob->error() << modifyJob->errorString();
-    cancelTask( i18n( "Unable to change item: %1", modifyJob->errorString() ) );
+    retryAfterFailure(modifyJob->errorString());
     return;
   }
 
@@ -789,7 +774,7 @@ void DavGroupwareResource::onItemChangedFinished( KJob *job )
 void DavGroupwareResource::onItemRemovedFinished( KJob *job )
 {
   if ( job->error() ) {
-    cancelTask( i18n( "Unable to remove item: %1", job->errorString() ) );
+    retryAfterFailure(job->errorString());
   }
   else {
     Akonadi::Item item = job->property( "item" ).value<Akonadi::Item>();
@@ -812,8 +797,11 @@ void DavGroupwareResource::onEtagChanged(const QString& itemUrl, const QString&
 
 bool DavGroupwareResource::configurationIsValid()
 {
-  if ( Settings::self()->remoteUrls().empty() )
+  if ( Settings::self()->remoteUrls().empty() ) {
+    emit status( NotConfigured, i18n( "The resource is not configured yet" ) );
+    cancelTask( i18n( "The resource is not configured yet" ) );
     return false;
+  }
 
   int newICT = Settings::self()->refreshInterval();
   if ( newICT == 0 )
@@ -835,6 +823,13 @@ bool DavGroupwareResource::configurationIsValid()
   return true;
 }
 
+void DavGroupwareResource::retryAfterFailure(const QString &errorMessage)
+{
+  emit status(Broken, errorMessage);
+  deferTask();
+  setTemporaryOffline(Settings::self()->refreshInterval() <= 0 ? 300 : Settings::self()->refreshInterval() * 60);
+}
+
 /*static*/
 void DavGroupwareResource::setCollectionIcon( Akonadi::Collection &collection )
 {
@@ -855,4 +850,3 @@ void DavGroupwareResource::setCollectionIcon( Akonadi::Collection &collection )
 
 AKONADI_RESOURCE_MAIN( DavGroupwareResource )
 
-#include "davgroupwareresource.moc"
