@@ -28,6 +28,14 @@
 
 #include <QtCore/QMap>
 
+#ifdef HAVE_ACCOUNTS
+namespace Accounts {
+  class Service;
+  class Account;
+  class Manager;
+};
+#endif
+
 class Settings : public SettingsBase
 {
   Q_OBJECT
@@ -109,6 +117,14 @@ class Settings : public SettingsBase
     QString password( DavUtils::Protocol protocol, const QString &url );
 
   private:
+#ifdef HAVE_ACCOUNTS
+    void addAccountsEnabledServices();
+    void removeAccountsDisabledServices();
+    void configureAccountService(Accounts::Account *acc, const Accounts::Service &service);
+    void importFromAccounts();
+    QString loadPasswordFromAccounts();
+    QString accountsUsername() const;
+#endif
     void buildUrlsList();
     void loadMappings();
     void updateRemoteUrls();
@@ -120,6 +136,9 @@ class Settings : public SettingsBase
     void updateToV3();
 
     WId mWinId;
+#ifdef HAVE_ACCOUNTS
+    Accounts::Manager *m_manager;
+#endif
     QString mResourceIdentifier;
     QMap<QString, UrlConfiguration*> mUrls;
     QMap<QString, QString> mPasswordsCache;
