@@ -24,6 +24,9 @@
 #include "settings.h"
 #include "settingsdialog.h"
 #include "timestampattribute.h"
+#ifdef HAVE_ACCOUNTS
+#include "../shared/getcredentialsjob.h"
+#endif
 
 #include <libkfbapi/friendlistjob.h>
 #include <libkfbapi/friendjob.h>
@@ -77,10 +80,39 @@ FacebookResource::~FacebookResource()
 
 void FacebookResource::configurationChanged()
 {
+#ifdef HAVE_ACCOUNTS
+  if ( Settings::self()->accountId() ) {
+    configureByAccount( Settings::self()->accountId() );
+  }
+#endif
   Settings::self()->writeConfig();
   synchronize();
 }
 
+#ifdef HAVE_ACCOUNTS
+void FacebookResource::configureByAccount( int accountId )
+{
+  kDebug() << "Starting credentials job";
+  GetCredentialsJob *gc = new GetCredentialsJob( accountId, this );
+  connect(gc, SIGNAL(finished(KJob*)), SLOT(slotGetCredentials(KJob*)));
+  gc->start();
+}
+
+void FacebookResource::slotGetCredentials(KJob *job)
+{
+  if (job->error()) {
+    return;// We will get kDebug from within the job if it fails
+  }
+
+  GetCredentialsJob *gJob = qobject_cast<GetCredentialsJob*>(job);
+  const QVariantMap data = gJob->credentialsData();
+  const QString accessToken = data.value(QLatin1String("AccessToken")).toString();
+  Settings::self()->setAccessToken(accessToken);
+
+  synchronize();
+}
+
+#endif
 void FacebookResource::aboutToQuit()
 {
   slotAbortRequested();
@@ -238,69 +270,81 @@ bool FacebookResource::retrieveItem( const Akonadi::Item &item, const QSet<QByte
 
 void FacebookResource::retrieveCollections()
 {
-  Collection friends;
-  friends.setRemoteId( friendsRID );
-  friends.setName( i18nc( "@title: addressbook name", "Friends on Facebook" ) );
-  friends.setParentCollection( Akonadi::Collection::root() );
-  friends.setContentMimeTypes( QStringList() << KABC::Addressee::mimeType() );
-  friends.setRights( Collection::ReadOnly );
-  EntityDisplayAttribute * const friendsDisplayAttribute = new EntityDisplayAttribute();
-  friendsDisplayAttribute->setIconName( QLatin1String("facebookresource") );
-  friends.addAttribute( friendsDisplayAttribute );
+  Collection::List collections;
+  if (Settings::self()->accountServices().contains(QLatin1String("facebook-contacts"))) {
+    Collection friends;
+    friends.setRemoteId( friendsRID );
+    friends.setName( i18nc( "@title: addressbook name", "Friends on Facebook" ) );
+    friends.setParentCollection( Akonadi::Collection::root() );
+    friends.setContentMimeTypes( QStringList() << KABC::Addressee::mimeType() );
+    friends.setRights( Collection::ReadOnly );
+    EntityDisplayAttribute * const friendsDisplayAttribute = new EntityDisplayAttribute();
+    friendsDisplayAttribute->setIconName( QLatin1String("facebookresource") );
+    friends.addAttribute( friendsDisplayAttribute );
+    collections << friends;
+  }
 
-  Collection events;
-  events.setRemoteId( eventsRID );
-  events.setName( i18nc( "@title: events collection title", "Events on Facebook" ) );
-  events.setParentCollection( Akonadi::Collection::root() );
-  events.setContentMimeTypes( QStringList() << QLatin1String("text/calendar") << eventMimeType );
-  events.setRights( Collection::ReadOnly );
-  EntityDisplayAttribute * const evendDisplayAttribute = new EntityDisplayAttribute();
-  evendDisplayAttribute->setIconName( QLatin1String("facebookresource") );
-  events.addAttribute( evendDisplayAttribute );
+  if (Settings::self()->accountServices().contains(QLatin1String("facebook-events"))) {
+    Collection events;
+    events.setRemoteId( eventsRID );
+    events.setName( i18nc( "@title: events collection title", "Events on Facebook" ) );
+    events.setParentCollection( Akonadi::Collection::root() );
+    events.setContentMimeTypes( QStringList() << QLatin1String("text/calendar") << eventMimeType );
+    events.setRights( Collection::ReadOnly );
+    EntityDisplayAttribute * const evendDisplayAttribute = new EntityDisplayAttribute();
+    evendDisplayAttribute->setIconName( QLatin1String("facebookresource") );
+    events.addAttribute( evendDisplayAttribute );
+    collections << events;
+  }
 
-  Collection notes;
-  notes.setRemoteId( notesRID );
-  notes.setName( i18nc( "@title: notes collection", "Notes on Facebook" ) );
-  notes.setParentCollection( Akonadi::Collection::root() );
-  notes.setContentMimeTypes( QStringList() << Akonadi::NoteUtils::noteMimeType() );
-  notes.setRights( Collection::ReadOnly );
-  EntityDisplayAttribute * const notesDisplayAttribute = new EntityDisplayAttribute();
-  notesDisplayAttribute->setIconName( QLatin1String("facebookresource") );
-  notes.addAttribute( notesDisplayAttribute );
+  if (Settings::self()->accountServices().contains(QLatin1String("facebook-notes"))) {
+    Collection notes;
+    notes.setRemoteId( notesRID );
+    notes.setName( i18nc( "@title: notes collection", "Notes on Facebook" ) );
+    notes.setParentCollection( Akonadi::Collection::root() );
+    notes.setContentMimeTypes( QStringList() << Akonadi::NoteUtils::noteMimeType() );
+    notes.setRights( Collection::ReadOnly );
+    EntityDisplayAttribute * const notesDisplayAttribute = new EntityDisplayAttribute();
+    notesDisplayAttribute->setIconName( QLatin1String("facebookresource") );
+    notes.addAttribute( notesDisplayAttribute );
+    collections << notes;
+  }
 
-  Collection posts;
-  posts.setRemoteId( postsRID );
-  posts.setName( i18nc( "@title: posts collection", "Posts on Facebook" ) );
-  posts.setParentCollection( Akonadi::Collection::root() );
-  posts.setContentMimeTypes( QStringList() << QLatin1String("text/x-vnd.akonadi.socialfeeditem") );
-  posts.setRights( Collection::CanCreateItem );
-  EntityDisplayAttribute * const postsDisplayAttribute = new EntityDisplayAttribute();
-  postsDisplayAttribute->setIconName( QLatin1String("facebookresource") );
-  //facebook's max post length is 63206 as of September 2012
-  //(Facebook ... Face Boo K ... hex(FACE) – K ... 64206 – 1000 = 63206)...don't ask me.
-  SocialNetworkAttributes * const socialAttributes =
-    new SocialNetworkAttributes( Settings::self()->userName(),
-                                 QLatin1String( "Facebook" ),
-                                 true,
-                                 63206 );
-  posts.addAttribute( postsDisplayAttribute );
-  posts.addAttribute( socialAttributes );
+  if (Settings::self()->accountServices().contains(QLatin1String("facebook-feed"))) {
+    Collection posts;
+    posts.setRemoteId( postsRID );
+    posts.setName( i18nc( "@title: posts collection", "Posts on Facebook" ) );
+    posts.setParentCollection( Akonadi::Collection::root() );
+    posts.setContentMimeTypes( QStringList() << QLatin1String("text/x-vnd.akonadi.socialfeeditem") );
+    posts.setRights( Collection::CanCreateItem );
+    EntityDisplayAttribute * const postsDisplayAttribute = new EntityDisplayAttribute();
+    postsDisplayAttribute->setIconName( QLatin1String("facebookresource") );
+    //facebook's max post length is 63206 as of September 2012
+    //(Facebook ... Face Boo K ... hex(FACE) – K ... 64206 – 1000 = 63206)...don't ask me.
+    SocialNetworkAttributes * const socialAttributes =
+      new SocialNetworkAttributes( Settings::self()->userName(),
+                                  QLatin1String( "Facebook" ),
+                                  true,
+                                  63206 );
+    posts.addAttribute( postsDisplayAttribute );
+    posts.addAttribute( socialAttributes );
+    collections << posts;
+  }
 
-  Collection notifications;
-  notifications.setRemoteId( notificationsRID );
-  notifications.setName( i18nc( "@title: notifications collection", "Notifications on Facebook" ) );
-  notifications.setParentCollection( Akonadi::Collection::root() );
-  notifications.setContentMimeTypes( QStringList() << QLatin1String("text/x-vnd.akonadi.socialnotification") );
-  notifications.setRights( Collection::ReadOnly );
-  EntityDisplayAttribute * const notificationsDisplayAttribute = new EntityDisplayAttribute();
-  notificationsDisplayAttribute->setIconName( QLatin1String("facebookresource") );
-  notifications.addAttribute( notificationsDisplayAttribute );
+  if (Settings::self()->accountServices().contains(QLatin1String("facebook-notifications"))) {
+    Collection notifications;
+    notifications.setRemoteId( notificationsRID );
+    notifications.setName( i18nc( "@title: notifications collection", "Notifications on Facebook" ) );
+    notifications.setParentCollection( Akonadi::Collection::root() );
+    notifications.setContentMimeTypes( QStringList() << QLatin1String("text/x-vnd.akonadi.socialnotification") );
+    notifications.setRights( Collection::ReadOnly );
+    EntityDisplayAttribute * const notificationsDisplayAttribute = new EntityDisplayAttribute();
+    notificationsDisplayAttribute->setIconName( QLatin1String("facebookresource") );
+    notifications.addAttribute( notificationsDisplayAttribute );
+    collections << notifications;
+  }
 
-  collectionsRetrieved( Collection::List() << friends
-                                           << events
-                                           << notes
-                                           << posts
-                                           << notifications );
+  collectionsRetrieved( collections );
 }
 
 void FacebookResource::itemRemoved( const Akonadi::Item &item )
