@@ -49,9 +49,7 @@ ImapIdleManager::ImapIdleManager( ResourceStateInterface::Ptr state,
 
 ImapIdleManager::~ImapIdleManager()
 {
-  if ( m_idle ) {
-    m_idle->stop();
-  }
+  stop();
   if ( m_pool ) {
     if ( m_sessionRequestId ) {
       m_pool->cancelSessionRequest( m_sessionRequestId );
@@ -62,6 +60,18 @@ ImapIdleManager::~ImapIdleManager()
   }
 }
 
+void ImapIdleManager::stop()
+{
+  if ( m_idle ) {
+    m_idle->stop();
+    disconnect(m_idle, 0, this, 0);
+    m_idle = 0;
+  }
+  if ( m_pool ) {
+    disconnect(m_pool, 0, this, 0);
+  }
+}
+
 KIMAP::Session *ImapIdleManager::session() const
 {
   return m_session;
@@ -171,6 +181,5 @@ void ImapIdleManager::onFlagsChanged( KIMAP::IdleJob *job )
   m_resource->synchronizeCollection( m_state->collection().id() );
 }
 
-#include "imapidlemanager.moc"
 
 
