@@ -33,10 +33,6 @@
 #include <kstandarddirs.h>
 #include <KWindowSystem>
 
-#ifndef IMAPRESOURCE_NO_SOLID
-#include <solid/networking.h>
-#endif
-
 #include <akonadi/agentmanager.h>
 #include <akonadi/attributefactory.h>
 #include <akonadi/collectionfetchjob.h>
@@ -74,12 +70,12 @@
 #include "movecollectiontask.h"
 #include "moveitemstask.h"
 #include "removecollectionrecursivetask.h"
-#include "removecollectiontask.h"
 #include "removeitemstask.h"
 #include "retrievecollectionmetadatatask.h"
 #include "retrievecollectionstask.h"
 #include "retrieveitemtask.h"
 #include "retrieveitemstask.h"
+#include "searchtask.h"
 
 #include "settingspasswordrequester.h"
 #include "sessionpool.h"
@@ -88,7 +84,6 @@
 #include "resourceadaptor.h"
 
 #ifdef MAIL_SERIALIZER_PLUGIN_STATIC
-#include <QtPlugin>
 
 Q_IMPORT_PLUGIN(akonadi_serializer_mail)
 #endif
@@ -184,15 +179,36 @@ ImapResource::ImapResource( const QString &id )
 
 ImapResource::~ImapResource()
 {
-  // Disconnect and destroy the pool now, otherwise it will be called from QObject
-  // destructor and at that point ResourceBase and most of other stuff is already
-  // destroyed, which causes a crash
-  m_pool->disconnect();
-  delete m_pool;
+  //Destroy everything that could cause callbacks immediately, otherwise the callbacks can result in a crash.
 
+  if ( m_idle ) {
+    delete m_idle;
+    m_idle = 0;
+  }
+
+  Q_FOREACH (ResourceTask* task, m_taskList) {
+    delete task;
+  }
+  m_taskList.clear();
+
+  delete m_pool;
   delete m_bodyCheckSession;
 }
 
+void ImapResource::aboutToQuit()
+{
+  //TODO the resource would ideally have to signal when it's done with logging out etc, before the destructor gets called
+  if ( m_idle ) {
+    m_idle->stop();
+  }
+
+  Q_FOREACH (ResourceTask* task, m_taskList) {
+    task->kill();
+  }
+
+  m_pool->disconnect();
+}
+
 void ImapResource::fetchItemsWithoutBodies( const Collection &collection,
                                             QObject* receiver, const char* slot)
 {
@@ -237,30 +253,32 @@ void ImapResource::fetchItemsWithoutBodiesDone( KJob *job )
                              Q_ARG( QList<qint64>, uids ) );
 }
 
-// ----------------------------------------------------------------------------------
+// -----------------------------------------------------------------------------
 
-int ImapResource::configureDialog( WId windowId )
+KDialog* ImapResource::createConfigureDialog(WId windowId)
 {
-  QPointer<SetupServer> dlg = new SetupServer( this, windowId );
+  SetupServer *dlg = new SetupServer( this, windowId );
   KWindowSystem::setMainWindow( dlg, windowId );
-
   dlg->setWindowIcon( KIcon( QLatin1String("network-server") ) );
-  int result = QDialog::Rejected;
-  if( dlg->exec() ) {
+  connect(dlg, SIGNAL(finished(int)), this, SLOT(onConfigurationDone(int)));;
+  return dlg;
+}
+
+void ImapResource::onConfigurationDone(int result)
+{
+  SetupServer *dlg = qobject_cast<SetupServer*>(sender());
+  if (result) {
     if ( dlg->shouldClearCache() ) {
       clearCache();
     }
     Settings::self()->writeConfig();
-    result = QDialog::Accepted;
   }
-  delete dlg;
-
-  return result;
+  dlg->deleteLater();
 }
 
 void ImapResource::configure( WId windowId )
 {
-  if ( configureDialog( windowId ) == QDialog::Accepted ) {
+  if ( createConfigureDialog( windowId )->exec() == QDialog::Accepted ) {
     emit configurationDialogAccepted();
     reconnect();
   } else {
@@ -276,7 +294,7 @@ void ImapResource::startConnect( const QVariant& )
 {
   if ( Settings::self()->imapServer().isEmpty() ) {
     setOnline( false );
-    emit status( Broken, i18n( "No server configured yet." ) );
+    emit status( NotConfigured, i18n( "No server configured yet." ) );
     taskDone();
     return;
   }
@@ -343,12 +361,13 @@ void ImapResource::onConnectDone( int errorCode, const QString &errorString )
   case SessionPool::IncompatibleServerError:
     setOnline( false );
     emit status( Broken, errorString );
-    taskDone();
+    cancelTask();
     return;
 
   case SessionPool::CouldNotConnectError:
-    setOnline( false );
-    taskDone();
+    emit status( Broken, errorString );
+    deferTask();
+    setTemporaryOffline((m_pool->account() && m_pool->account()->timeout() > 0) ? m_pool->account()->timeout() : 300);
     return;
 
   case SessionPool::ReconnectNeededError:
@@ -468,18 +487,6 @@ void ImapResource::retrieveCollections()
   queueTask( task );
 }
 
-void ImapResource::retrieveCollectionAttributes( const Akonadi::Collection &collection )
-{
-  emit status( AgentBase::Running, i18nc( "@info:status", "Retrieving folder attributes for '%1'", collection.name() ) );
-
-  ResourceStateInterface::Ptr state = ::ResourceState::createRetrieveCollectionMetadataState( this, collection );
-
-  RetrieveCollectionMetadataTask *task = new RetrieveCollectionMetadataTask( state, this );
-  task->setSpontaneous( false );
-  task->start( m_pool );
-  queueTask( task );
-}
-
 void ImapResource::triggerCollectionExtraInfoJobs( const QVariant &collectionVariant )
 {
   const Collection collection( collectionVariant.value<Collection>() );
@@ -561,6 +568,38 @@ void ImapResource::collectionMoved( const Akonadi::Collection &collection, const
 
 
 
+void ImapResource::addSearch(const QString& query, const QString& queryLanguage, const Collection& resultCollection)
+{
+}
+
+void ImapResource::removeSearch(const Collection& resultCollection)
+{
+}
+
+void ImapResource::search( const QString &query, const Collection &collection )
+{
+  QVariantMap arg;
+  arg[QLatin1String("query")] = query;
+  arg[QLatin1String("collection")] = QVariant::fromValue( collection );
+  scheduleCustomTask( this, "doSearch", arg );
+}
+
+void ImapResource::doSearch( const QVariant &arg )
+{
+  const QVariantMap map = arg.toMap();
+  const QString query = map[QLatin1String("query")].toString();
+  const Collection collection = map[QLatin1String("collection")].value<Collection>();
+
+  ResourceStateInterface::Ptr state = ::ResourceState::createSearchState( this, collection );
+  emit status( AgentBase::Running, i18nc( "@info:status", "Searching..." ) );
+  SearchTask *task = new SearchTask( state, query, this );
+  task->start( m_pool );
+  queueTask( task );
+}
+
+
+// -----
+
 // ----------------------------------------------------------------------------------
 
 void ImapResource::scheduleConnectionAttempt()
@@ -575,13 +614,20 @@ void ImapResource::doSetOnline(bool online)
   kDebug() << "online=" << online;
 #endif
   if ( !online ) {
-    if ( m_pool->isConnected() )
-      m_pool->disconnect();
-    Q_FOREACH(ResourceTask* task, m_taskList)
+    Q_FOREACH(ResourceTask* task, m_taskList) {
       task->kill();
+      delete task;
+    }
     m_taskList.clear();
-    delete m_idle;
-    m_idle = 0;
+    m_pool->cancelPasswordRequests();
+    if (m_pool->isConnected()) {
+        m_pool->disconnect();
+    }
+    if (m_idle) {
+      m_idle->stop();
+      delete m_idle;
+      m_idle = 0;
+    }
     Settings::self()->clearCachedPassword();
   } else if ( online && !m_pool->isConnected() ) {
     scheduleConnectionAttempt();
@@ -615,15 +661,7 @@ void ImapResource::reconnect()
 {
   setNeedsNetwork( needsNetwork() );
   setOnline( false ); // we are not connected initially
-
-  setOnline( !needsNetwork()
-#ifndef IMAPRESOURCE_NO_SOLID
-                         ||
-             Solid::Networking::status() == Solid::Networking::Unknown ||
-             Solid::Networking::status() == Solid::Networking::Connected
-#endif
-             );
-
+  setOnline( true );
 }
 
 
@@ -796,4 +834,3 @@ void ImapResource::clearStatusMessage()
 
 AKONADI_RESOURCE_MAIN( ImapResource )
 
-#include "imapresource.moc"
