@@ -27,6 +27,8 @@
 #define RESOURCES_IMAP_IMAPRESOURCE_H
 
 #include <akonadi/resourcebase.h>
+#include <akonadi/agentsearchinterface.h>
+#include <KDialog>
 #include <QPointer>
 
 class QTimer;
@@ -37,13 +39,14 @@ namespace KIMAP
   class Session;
 }
 
-class ImapAccount;
 class ImapIdleManager;
 class SessionPool;
 class ResourceState;
 class SubscriptionDialog;
 
-class ImapResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::ObserverV3
+class ImapResource : public Akonadi::ResourceBase,
+                     public Akonadi::AgentBase::ObserverV3,
+                     public Akonadi::AgentSearchInterface
 {
   Q_OBJECT
   Q_CLASSINFO( "D-Bus Interface", "org.kde.Akonadi.Imap.Resource" )
@@ -55,7 +58,7 @@ public:
   ~ImapResource();
 
 
-  int configureDialog( WId windowId );
+  KDialog *createConfigureDialog( WId windowId );
   QStringList serverCapabilities() const;
 
   void fetchItemsWithoutBodies( const Akonadi::Collection &collection, QObject *receiver, const char *slot );
@@ -77,7 +80,6 @@ protected Q_SLOTS:
   void abortActivity();
 
   void retrieveCollections();
-  void retrieveCollectionAttributes( const Akonadi::Collection &collection );
 
   void retrieveItems( const Akonadi::Collection &col );
   bool retrieveItem( const Akonadi::Item &item, const QSet<QByteArray> &parts );
@@ -97,13 +99,20 @@ protected:
   virtual void collectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &source,
                                 const Akonadi::Collection &destination );
 
+  virtual void addSearch( const QString &query, const QString &queryLanguage, const Akonadi::Collection &resultCollection );
+  virtual void removeSearch( const Akonadi::Collection &resultCollection );
+  virtual void search( const QString &query, const Akonadi::Collection &collection );
 
   virtual void doSetOnline(bool online);
 
   QChar separatorCharacter() const;
   void setSeparatorCharacter( const QChar &separator );
 
+  virtual void aboutToQuit();
+
 private Q_SLOTS:
+  void doSearch( const QVariant &arg );
+
   void reconnect();
 
   void scheduleConnectionAttempt();
@@ -127,6 +136,7 @@ private Q_SLOTS:
   void clearStatusMessage();
 
   void fetchItemsWithoutBodiesDone( KJob *job );
+  void onConfigurationDone( int result );
 
 private:
   friend class ResourceState;
