@@ -67,8 +67,6 @@ public:
   virtual void setIdleCollection( const Akonadi::Collection &collection ) = 0;
   virtual void applyCollectionChanges( const Akonadi::Collection &collection ) = 0;
 
-  virtual void collectionAttributesRetrieved( const Akonadi::Collection &collection ) = 0;
-
   virtual void itemRetrieved( const Akonadi::Item &item ) = 0;
 
   virtual void itemsRetrieved( const Akonadi::Item::List &items ) = 0;
@@ -85,6 +83,8 @@ public:
 
   virtual void changeProcessed() = 0;
 
+  virtual void searchFinished( const QVector<qint64> &result, bool isRid = true ) = 0;
+
   virtual void cancelTask( const QString &errorString ) = 0;
   virtual void deferTask() = 0;
   virtual void taskDone() = 0;
