@@ -245,12 +245,6 @@ void ResourceTask::applyCollectionChanges( const Akonadi::Collection &collection
   m_resource->applyCollectionChanges( collection );
 }
 
-void ResourceTask::collectionAttributesRetrieved( const Akonadi::Collection &collection )
-{
-  m_resource->collectionAttributesRetrieved( collection );
-  deleteLater();
-}
-
 void ResourceTask::itemRetrieved( const Akonadi::Item &item )
 {
   m_resource->itemRetrieved( item );
@@ -287,6 +281,12 @@ void ResourceTask::changesCommitted(const Akonadi::Item::List& items)
   deleteLater();
 }
 
+void ResourceTask::searchFinished( const QVector<qint64> &result, bool isRid )
+{
+  m_resource->searchFinished( result, isRid );
+  deleteLater();
+}
+
 void ResourceTask::collectionsRetrieved( const Akonadi::Collection::List &collections )
 {
   m_resource->collectionsRetrieved( collections );
@@ -462,5 +462,12 @@ bool ResourceTask::serverSupportsAnnotations() const
             || serverCapabilities().contains( QLatin1String( "ANNOTATEMORE" ) );
 }
 
+bool ResourceTask::serverSupportsCondstore() const
+{
+    // Don't enable CONDSTORE for GMail (X-GM-EXT-1 is a GMail-specific capability)
+    // because it breaks changes synchronization when using labels.
+    return serverCapabilities().contains( QLatin1String( "CONDSTORE" ) ) &&
+            !serverCapabilities().contains( QLatin1String( "X-GM-EXT-1" ) );
+}
+
 
-#include "resourcetask.moc"
