@@ -92,8 +92,6 @@ protected:
   void setIdleCollection( const Akonadi::Collection &collection );
   void applyCollectionChanges( const Akonadi::Collection &collection );
 
-  void collectionAttributesRetrieved( const Akonadi::Collection &collection );
-
   void itemRetrieved( const Akonadi::Item &item );
 
   void itemsRetrieved( const Akonadi::Item::List &items );
@@ -110,6 +108,8 @@ protected:
 
   void changeProcessed();
 
+  void searchFinished( const QVector<qint64> &result, bool isRid = true );
+
   void cancelTask( const QString &errorString );
   void deferTask();
   void taskDone();
@@ -131,6 +131,7 @@ protected:
   static QList<QByteArray> toAkonadiFlags( const QList<QByteArray> &flags );
 
   bool serverSupportsAnnotations() const;
+  bool serverSupportsCondstore() const;
 
 private:
 
