@@ -32,13 +32,8 @@
 #include "settings.h"
 #include "imapresource.h"
 #include "serverinfodialog.h"
+#include "resources/folderarchivesettings/folderarchivesettingpage.h"
 
-#include <QButtonGroup>
-#include <QGridLayout>
-#include <QGroupBox>
-#include <QLabel>
-#include <QProgressBar>
-#include <QRadioButton>
 
 #include <mailtransport/transport.h>
 #include <mailtransport/servertest.h>
@@ -131,6 +126,8 @@ SetupServer::SetupServer( ImapResource *parentResource, WId parent )
 {
   Settings::self()->setWinId( parent );
   m_ui->setupUi( mainWidget() );
+  m_folderArchiveSettingPage = new FolderArchiveSettingPage(m_parentResource->identifier());
+  m_ui->tabWidget->addTab(m_folderArchiveSettingPage, i18n("Folder Archive"));
   m_ui->safeImapGroup->setId( m_ui->noRadio, KIMAP::LoginJob::Unencrypted );
   m_ui->safeImapGroup->setId( m_ui->sslRadio, KIMAP::LoginJob::AnySslVersion );
   m_ui->safeImapGroup->setId( m_ui->tlsRadio, KIMAP::LoginJob::TlsV1 );
@@ -258,6 +255,7 @@ void SetupServer::slotCustomSieveChanged()
 
 void SetupServer::applySettings()
 {
+  m_folderArchiveSettingPage->writeSettings();
   m_shouldClearCache = ( Settings::self()->imapServer() != m_ui->imapServer->text() )
                     || ( Settings::self()->userName() != m_ui->userName->text() );
 
@@ -339,6 +337,7 @@ void SetupServer::applySettings()
 
 void SetupServer::readSettings()
 {
+  m_folderArchiveSettingPage->loadSettings();
   m_ui->accountName->setText( m_parentResource->name() );
   m_oldResourceName = m_ui->accountName->text();
 
@@ -659,4 +658,3 @@ void SetupServer::populateDefaultAuthenticationOptions()
 
 
 
-#include "setupserver.moc"
