@@ -42,7 +42,7 @@ namespace KPIMIdentities
 class IdentityCombo;
 class IdentityManager;
 }
-
+class FolderArchiveSettingPage;
 class ImapResource;
 
 /**
@@ -94,6 +94,7 @@ private:
   QString m_oldResourceName;
   QRegExpValidator mValidator;
   Akonadi::Collection mOldTrash;
+  FolderArchiveSettingPage *m_folderArchiveSettingPage;
 
 private slots:
   void slotTest();
