@@ -33,7 +33,6 @@ class QKeyEvent;
 class QStandardItemModel;
 class QStandardItem;
 
-class KDescendantsProxyModel;
 class KLineEdit;
 class QCheckBox;
 class ImapAccount;
@@ -95,6 +94,7 @@ private slots:
   void onItemChanged( QStandardItem *item );
   void onMobileLineEditChanged( const QString &text );
 
+  void slotSearchPattern(const QString &pattern);
 protected:
   /* reimp */ void keyPressEvent( QKeyEvent *event );
 
