@@ -323,11 +323,10 @@ private slots:
 
     RetrieveCollectionsTask *task = new RetrieveCollectionsTask( state );
     task->start( &pool );
-    QTest::qWait( 100 );
 
     Akonadi::Collection::List collections;
 
-    QCOMPARE( state->calls().count(), callNames.size() );
+    QTRY_COMPARE( state->calls().count(), callNames.size() );
     for ( int i = 0; i < callNames.size(); i++ ) {
       QString command = QString::fromUtf8(state->calls().at( i ).first);
       QVariant parameter = state->calls().at( i ).second;
