@@ -30,7 +30,7 @@
 #include <Akonadi/CollectionModifyJob>
 #include <Akonadi/EntityDisplayAttribute>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 SetupDefaultFoldersJob::SetupDefaultFoldersJob( const Akonadi::AgentInstance &instance,
                                                 QObject *parent )
@@ -100,8 +100,7 @@ void SetupDefaultFoldersJob::collectionFetchResult( KJob *job )
     Akonadi::CollectionAnnotationsAttribute *attr = 0;
     if ( ( attr = col.attribute<Akonadi::CollectionAnnotationsAttribute>() ) ) {
       folderType =
-        KolabV2::folderTypeFromString(
-          attr->annotations().value( KOLAB_FOLDER_TYPE_ANNOTATION ) );
+        KolabV2::folderTypeFromString( Kolab::getFolderTypeAnnotation( attr->annotations() ) );
     }
     KolabV2::FolderType guessedType = KolabV2::guessFolderTypeFromName( col.name() );
 
@@ -142,10 +141,7 @@ void SetupDefaultFoldersJob::collectionFetchResult( KJob *job )
         col.attribute<Akonadi::CollectionAnnotationsAttribute>( Akonadi::Entity::AddIfMissing );
 
       QMap<QByteArray, QByteArray> annotations;
-      annotations.insert(
-        KOLAB_FOLDER_TYPE_ANNOTATION,
-        KolabV2::folderTypeToString( static_cast<KolabV2::FolderType>( i ), true ) );
-
+      Kolab::setFolderTypeAnnotation( annotations, KolabV2::folderTypeToString( static_cast<KolabV2::FolderType>( i ), true ) );
       attr->setAnnotations( annotations );
       if ( !iconName.isEmpty() ) {
         Akonadi::EntityDisplayAttribute *attribute =
@@ -162,10 +158,7 @@ void SetupDefaultFoldersJob::collectionFetchResult( KJob *job )
         col.attribute<Akonadi::CollectionAnnotationsAttribute>( Akonadi::Entity::AddIfMissing );
 
       QMap<QByteArray, QByteArray> annotations;
-      annotations.insert(
-        KOLAB_FOLDER_TYPE_ANNOTATION,
-        KolabV2::folderTypeToString( static_cast<KolabV2::FolderType>( i ), true ) );
-
+      Kolab::setFolderTypeAnnotation( annotations, KolabV2::folderTypeToString( static_cast<KolabV2::FolderType>( i ), true ) );
       attr->setAnnotations( annotations );
       if ( !iconName.isEmpty() ) {
         Akonadi::EntityDisplayAttribute *attribute =
@@ -180,4 +173,3 @@ void SetupDefaultFoldersJob::collectionFetchResult( KJob *job )
   emitResult();
 }
 
-#include "setupdefaultfoldersjob.moc"
