@@ -47,7 +47,7 @@
 
 #include <kpimutils/kfileio.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QDir>
 #include <QFileInfo>
@@ -328,13 +328,16 @@ class MaildirContext
       if ( !result.isEmpty() && mHasIndexData ) {
         mIndexData.insert( result, KMIndexDataPtr( new KMIndexData ) );
         Q_ASSERT( mIndexData.value( result )->isEmpty() );
+      } else {
+        //TODO: use the error string?
+        kWarning() << mMaildir.lastError();
       }
 
       return result;
     }
 
     void writeEntry( const QString &key, const QByteArray &data ) {
-      mMaildir.writeEntry( key, data );
+      mMaildir.writeEntry( key, data ); //TODO: error handling
       if ( mHasIndexData ) {
         mIndexData.insert( key, KMIndexDataPtr( new KMIndexData ) );
       }
@@ -359,6 +362,9 @@ class MaildirContext
         if ( destination.mHasIndexData ) {
           destination.mIndexData.insert( result, KMIndexDataPtr( new KMIndexData ) );
         }
+      } else {
+        //TODO error handling?
+        kWarning() << mMaildir.lastError();
       }
 
       return result;
@@ -373,7 +379,11 @@ class MaildirContext
     }
 
     bool isValid( QString &error ) const {
-      return mMaildir.isValid( error );
+      bool result = mMaildir.isValid();
+      if ( !result ) {
+        error = mMaildir.lastError();
+      }
+      return result;
     }
 
     bool isValidEntry( const QString &entry ) const {
@@ -839,7 +849,7 @@ bool MixedMaildirStore::Private::fillItem( MBoxPtr &mbox, bool includeHeaders, b
   }
 
   item.setModificationTime( mbox->modificationTime() );
-
+  
   // TODO: size?
 
   if ( includeHeaders || includeBody ) {
@@ -865,7 +875,7 @@ bool MixedMaildirStore::Private::fillItem( const MaildirPtr &md, bool includeHea
   const qint64 entrySize = md->maildir().size( item.remoteId() );
   if ( entrySize < 0 )
     return false;
-  
+
   item.setSize( entrySize );
   item.setModificationTime( md->maildir().lastModified( item.remoteId() ) );
 
@@ -954,7 +964,7 @@ void MixedMaildirStore::Private::updateContextHashes( const QString &oldPath, co
 
 bool MixedMaildirStore::Private::visit( FileStore::Job *job )
 {
-  const QString message = i18nc( "@info:status", "Unhandled operation %1", job->metaObject()->className() );
+  const QString message = i18nc( "@info:status", "Unhandled operation %1", QLatin1String(job->metaObject()->className()) );
   kError() << message;
   q->notifyError( FileStore::Job::InvalidJobContext, message );
   return false;
@@ -1741,7 +1751,7 @@ bool MixedMaildirStore::Private::visit( FileStore::ItemModifyJob *job )
   const bool payloadChangedButIgnored = payloadChanged && job->ignorePayload();
   const bool ignoreModifyIfValid = nothingChanged ||
                                    ( payloadChangedButIgnored && !flagsChanged );
-  
+
   Item item = job->item();
   const Collection collection = item.parentCollection();
   QString path;
@@ -1801,7 +1811,7 @@ bool MixedMaildirStore::Private::visit( FileStore::ItemModifyJob *job )
       q->notifyItemsProcessed( Item::List() << item );
       return true;
     }
- 
+
     // make sure to read the index (if available) before modifying the data, which would
     // make the index invalid
     mbox->readIndexData();
@@ -1875,8 +1885,8 @@ bool MixedMaildirStore::Private::visit( FileStore::ItemModifyJob *job )
       Maildir md( mdPtr->maildir() );
       newKey = md.changeEntryFlags( item.remoteId(), item.flags() );
       if ( newKey.isEmpty() ) {
-        errorText = i18nc( "@info:status", "Cannot modify emails in folder %1",
-                            collection.name() );
+        errorText = i18nc( "@info:status", "Cannot modify emails in folder %1. %2",
+                            collection.name(), md.lastError() );
         kError() << errorText << "FolderType=" << folderType;
         q->notifyError( FileStore::Job::InvalidJobContext, errorText );
         return false;
@@ -2276,7 +2286,7 @@ void MixedMaildirStore::setTopLevelCollection( const Collection &collection )
 
   CachePolicy cachePolicy;
   cachePolicy.setInheritFromParent( false );
-  cachePolicy.setLocalParts( QStringList() << MessagePart::Envelope );
+  cachePolicy.setLocalParts( QStringList() << QLatin1String(MessagePart::Envelope) );
   cachePolicy.setSyncOnDemand( true );
   cachePolicy.setCacheTimeout( 1 );
 
@@ -2352,6 +2362,5 @@ void MixedMaildirStore::checkItemFetch( FileStore::ItemFetchJob *job, int &error
   }
 }
 
-#include "mixedmaildirstore.moc"
 
 // kate: space-indent on; indent-width 2; replace-tabs on;
