@@ -25,7 +25,7 @@
 #include <KAssistantDialog>
 #include <KDebug>
 #include <KFileDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KVBox>
 
 RestoreAssistant::RestoreAssistant( QWidget *parent ) : KAssistantDialog( parent ), m_selectFileButton(0)
@@ -102,4 +102,3 @@ void RestoreAssistant::slotRestoreComplete( bool ok )
                                                "report a bug, so we can find out what the cause is." ) );
 }
 
-#include "restoreassistant.moc"
